pub struct DelayedLogger { /* private fields */ }Expand description
A tracing::Subscriber that prints the events deemed most important to get a
high-level overview of the executed algorithm to stdout.
Features:
- Messages are only printed after the algorithm has spent a certain time in the current span, thus not printing anything for short spans
- Messages are printed from the same threads as they are generated, which makes it compatible with IO capturing during tests
- for each root span, all logged sub-spans and events are written in a single line, keeping the output compact.
- to make the single line easier to read, every second-level span (and its
sub-tree) is printed in a different color, cycling through a fixed palette.
Colors are only emitted when the feature
print_coloredis active and the output stream supports them; Furthermore, they can be disabled via the theNO_COLORandCLICOLORenvironment variables.
Implementations
Sourceimpl DelayedLogger
impl DelayedLogger
Sourcepub fn new(
max_depth: usize,
silent_period: u64,
levels: RangeInclusive<Level>,
) -> Self
pub fn new( max_depth: usize, silent_period: u64, levels: RangeInclusive<Level>, ) -> Self
Creates a new DelayedLogger, which logs only events and spans
- whose
Levelis withinlevels - which are part of a span that will be running for at least
silent_periodmicroseconds; any message queued at a time when this is not yet decided will be stored and possibly printed later - are part of a span of depth at most
max_depthin the span tree
Sourcepub fn init(max_depth: usize, silent_period: u64, levels: RangeInclusive<Level>)
pub fn init(max_depth: usize, silent_period: u64, levels: RangeInclusive<Level>)
Creates a new DelayedLogger using DelayedLogger::new() and sets it as
the global default. This will panic if a global default has already been set.
Sourcepub fn init_test()
pub fn init_test()
Creates a new DelayedLogger using a test configuration and sets it as
the global default, unless a global default is already set.